/*
  Q Light Controller - Unit tests
  qlcfixturedefcache_test.h

  Copyright (C) Heikki Junnila

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0.txt

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

#ifndef QLCFIXTUREDEFCACHE_TEST_H
#define QLCFIXTUREDEFCACHE_TEST_H

#include <QObject>
#include "qlcfixturedefcache.h"

class QLCFixtureDefCache_Test : public QObject
{
    Q_OBJECT

private slots:
    void init();
    void cleanup();

    void duplicates();
    void add();
    void reload();
    void fixtureDef();
	void load();
    void defDirectories();
    void storeDef();

private:
    QLCFixtureDefCache cache;
};

#endif
